Examples
========

Various example notebooks.

.. toctree::
   :maxdepth: 1

   examples/example_cli_famos.ipynb
   examples/visualization.ipynb
   examples/workflow_cli.ipynb
   examples/workflow_python.ipynb
